Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func DetectOutliers ¶
DetectOutliers checks for sudden abnormal price movement (e.g. > threshold % in 1 bar)
func GenerateTestFile ¶
func GenerateTestFile(info *StrategyInfo) string
GenerateTestFile generates a test file template for a strategy
func ValidateOHLCV ¶
Types ¶
type StrategyInfo ¶
StrategyInfo holds information about a strategy for test generation
func ExtractStrategyInfo ¶
func ExtractStrategyInfo(filename string, src []byte) (*StrategyInfo, error)
ExtractStrategyInfo extracts strategy information from source code
type ValidationError ¶
ValidationError represents a code validation error
func ValidateStrategy ¶
func ValidateStrategy(filename string, src []byte) ([]ValidationError, error)
ValidateStrategy is a convenience function for validating strategy code
func (*ValidationError) Error ¶
func (e *ValidationError) Error() string
Click to show internal directories.
Click to hide internal directories.